Package 'flandersqmd'

Title: Auxiliary Function for the Flandersqmd Quarto Extensions
Description: Prepare new documents using the Flandersqmd extensions.
Authors: Thierry Onkelinx [aut, cre] (ORCID: <https://orcid.org/0000-0001-8804-4216>, affiliation: Research Institute for Nature and Forest (INBO)), Research Institute for Nature and Forest (INBO) [cph, fnd] (ROR: <https://ror.org/00j54wy13>)
Maintainer: Thierry Onkelinx <[email protected]>
License: GPL-3
Version: 0.0.3
Built: 2026-05-22 10:32:10 UTC
Source: https://github.com/inbo/flandersqmd

Help Index


Add an abstract file to a Quarto report

Description

This function adds an abstract file to a Quarto report.

Usage

add_abstract(report_path = ".")

Arguments

report_path

The path to the folder containing the report. Defaults to the current working directory.

Value

The name of the index file.


Format an address in YAML

Description

Format an address in YAML

Usage

add_address(type = "client")

Arguments

type

The type of address. Defaults to "client".

Value

A character vector containing the formatted address.


Add an author or reviewer to the ⁠_quarto.yml⁠ file

Description

Add an author or reviewer to the ⁠_quarto.yml⁠ file

Usage

add_author(report_path = ".", reviewer = FALSE)

Arguments

report_path

The path to the folder containing the report. Defaults to the current working directory.

reviewer

If TRUE, the person is added as a reviewer. Defaults to FALSE. If FALSE, the person is added as an author.

Value

The path to the ⁠_quarto.yml⁠ file.


Add a bibliography file to a Quarto report

Description

This function adds a bibliography file to a Quarto report.

Usage

add_bibliography(report_path = ".")

Arguments

report_path

The path to the folder containing the report. Defaults to the current working directory.

Value

The name of the bibliography file.


Add a chapter file to a Quarto report

Description

This function adds a chapter file to a Quarto report.

Usage

add_chapter(report_path = ".", title, filename, toc = TRUE)

Arguments

report_path

The path to the folder containing the report. Defaults to the current working directory.

title

The title of the chapter. If missing, the chapter is assumed the introduction with a default title based on the language.

filename

The name of the chapter file. If missing, the chapter is assumed the introduction with a default filename based on the language.

toc

A logical value indicating whether to add a local table of contents. Defaults to TRUE.

Value

The name of the chapter file.


Add cover to ⁠_quarto.yml⁠

Description

Add cover to ⁠_quarto.yml⁠

Usage

add_cover(report_path = ".", cover_pdf)

Arguments

report_path

The path to the folder containing the report. Defaults to the current working directory.

cover_pdf

The path to a PDF file. The first page of this PDF file will be used as the cover of the report.


Add an index file to a Quarto report

Description

This function adds an index file to a Quarto report.

Usage

add_index(report_path = ".")

Arguments

report_path

The path to the folder containing the report. Defaults to the current working directory.

Value

The name of the index file.


Add a recommendations section to a flandersqmd report

Description

This function adds a recommendations section to a flandersqmd report. The file also add a table of contents, a list of figures and a list of tables to the pdf version of the report.

Usage

add_recommendations(report_path = ".", lof = TRUE, lot = TRUE)

Arguments

report_path

The path to the folder containing the report. Defaults to the current working directory.

lof

A logical value indicating whether to add a list of figures. Defaults to TRUE. If TRUE, a list of figures is added to the pdf version of the report.

lot

A logical value indicating whether to add a list of tables. Defaults to TRUE. If TRUE, a list of tables is added to the pdf version of the report.


Convert a data frame with author information to YAML format

Description

Convert a data frame with author information to YAML format

Usage

author2yaml(author, corresponding = FALSE)

Arguments

author

a data frame with author information. It should contain the columns:

  • given: the given name of the author

  • family: the family name of the author

  • email: the email address of the author (optional)

  • orcid: the ORCID of the author (optional)

  • affiliation: the affiliation of the author (optional)

corresponding

a logical value indicating whether the author is the corresponding author. If TRUE, the email address of the author must be provided.

Value

a character vector containing the YAML representation of the author


Create a template for a flandersqmd report

Description

Create a template for a flandersqmd report

Usage

create_report(path = ".", reportname, version = "main", shortname)

Arguments

path

The folder in which to create the folder containing the report. Defaults to the current working directory. It also creates an RStudio project file in the report folder. When ran from RStudio, the project will be opened automatically in a new session.

reportname

The folder name of the report. The location of the folder reportname depends on the content of path. When path is a checklist::checklist project, you will find the new report at path/source/reportname. When path is a checklist::checklist package, you will find the new report at path/inst/reportname. Otherwise you will find the new report at path/reportname.

version

The version of the flandersqmd-book extension to use. Defaults to "main", which refers to the current version.

shortname

Deprecated. Use reportname instead.

See Also

Other utils: inbo_website()


Render the report into a zip file for the INBO website

Description

Render the report into a zip file for the INBO website

Usage

inbo_website(path = ".")

Arguments

path

The path to the directory where the report is located

See Also

Other utils: create_report()


Insert missing metadata in ⁠_quarto.yml⁠

Description

Insert missing metadata in ⁠_quarto.yml⁠

Usage

insert_missing_metadata(report_path = ".")

Arguments

report_path

The path to the folder containing the report. Defaults to the current working directory.


Post render function

Description

Post render function

Usage

post_render()