| Title: | Auxiliary Function for the Flandersqmd Quarto Extensions |
|---|---|
| Description: | Prepare new documents using the Flandersqmd extensions. |
| Authors: | Thierry Onkelinx [aut, cre] (ORCID: <https://orcid.org/0000-0001-8804-4216>, affiliation: Research Institute for Nature and Forest (INBO)), Research Institute for Nature and Forest (INBO) [cph, fnd] (ROR: <https://ror.org/00j54wy13>) |
| Maintainer: | Thierry Onkelinx <[email protected]> |
| License: | GPL-3 |
| Version: | 0.0.3 |
| Built: | 2026-05-22 10:32:10 UTC |
| Source: | https://github.com/inbo/flandersqmd |
This function adds an abstract file to a Quarto report.
add_abstract(report_path = ".")add_abstract(report_path = ".")
report_path |
The path to the folder containing the report. Defaults to the current working directory. |
The name of the index file.
Format an address in YAML
add_address(type = "client")add_address(type = "client")
type |
The type of address.
Defaults to |
A character vector containing the formatted address.
_quarto.yml fileAdd an author or reviewer to the _quarto.yml file
add_author(report_path = ".", reviewer = FALSE)add_author(report_path = ".", reviewer = FALSE)
report_path |
The path to the folder containing the report. Defaults to the current working directory. |
reviewer |
If |
The path to the _quarto.yml file.
This function adds a bibliography file to a Quarto report.
add_bibliography(report_path = ".")add_bibliography(report_path = ".")
report_path |
The path to the folder containing the report. Defaults to the current working directory. |
The name of the bibliography file.
This function adds a chapter file to a Quarto report.
add_chapter(report_path = ".", title, filename, toc = TRUE)add_chapter(report_path = ".", title, filename, toc = TRUE)
report_path |
The path to the folder containing the report. Defaults to the current working directory. |
title |
The title of the chapter. If missing, the chapter is assumed the introduction with a default title based on the language. |
filename |
The name of the chapter file. If missing, the chapter is assumed the introduction with a default filename based on the language. |
toc |
A logical value indicating whether to add a local table of
contents.
Defaults to |
The name of the chapter file.
_quarto.yml
Add cover to _quarto.yml
add_cover(report_path = ".", cover_pdf)add_cover(report_path = ".", cover_pdf)
report_path |
The path to the folder containing the report. Defaults to the current working directory. |
cover_pdf |
The path to a PDF file. The first page of this PDF file will be used as the cover of the report. |
This function adds an index file to a Quarto report.
add_index(report_path = ".")add_index(report_path = ".")
report_path |
The path to the folder containing the report. Defaults to the current working directory. |
The name of the index file.
flandersqmd reportThis function adds a recommendations section to a flandersqmd report.
The file also add a table of contents, a list of figures and a list of
tables to the pdf version of the report.
add_recommendations(report_path = ".", lof = TRUE, lot = TRUE)add_recommendations(report_path = ".", lof = TRUE, lot = TRUE)
report_path |
The path to the folder containing the report. Defaults to the current working directory. |
lof |
A logical value indicating whether to add a list of figures.
Defaults to |
lot |
A logical value indicating whether to add a list of tables.
Defaults to |
Convert a data frame with author information to YAML format
author2yaml(author, corresponding = FALSE)author2yaml(author, corresponding = FALSE)
author |
a data frame with author information. It should contain the columns:
|
corresponding |
a logical value indicating whether the author is the
corresponding author.
If |
a character vector containing the YAML representation of the author
flandersqmd reportCreate a template for a flandersqmd report
create_report(path = ".", reportname, version = "main", shortname)create_report(path = ".", reportname, version = "main", shortname)
path |
The folder in which to create the folder containing the report. Defaults to the current working directory. It also creates an RStudio project file in the report folder. When ran from RStudio, the project will be opened automatically in a new session. |
reportname |
The folder name of the report.
The location of the folder |
version |
The version of the |
shortname |
Deprecated.
Use |
Other utils:
inbo_website()
Render the report into a zip file for the INBO website
inbo_website(path = ".")inbo_website(path = ".")
path |
The path to the directory where the report is located |
Other utils:
create_report()
_quarto.yml
Insert missing metadata in _quarto.yml
insert_missing_metadata(report_path = ".")insert_missing_metadata(report_path = ".")
report_path |
The path to the folder containing the report. Defaults to the current working directory. |